@@ -1,5 +1,5 @@
 /*
- * Copyright 2010-2024 The pygit2 contributors
+ * Copyright 2010-2025 The pygit2 contributors
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2,
@@ -1065,7 +1065,8 @@ Repository_create_commit(Repository *self, PyObject *args)
 
     err = git_commit_create(&oid, self->repo, update_ref,
                             py_author->signature, py_committer->signature,
-                            encoding, message, tree, parent_count, parents);
+                            encoding, message, tree, parent_count,
+                            (const git_commit **)parents);
     if (err < 0) {
         Error_set(err);
         goto out;
@@ -1147,7 +1148,8 @@ Repository_create_commit_string(Repository *self, PyObject *args)
 
     err = git_commit_create_buffer(&buf, self->repo,
                                    py_author->signature, py_committer->signature,
-                                   encoding, message, tree, parent_count, parents);
+                                   encoding, message, tree, parent_count,
+                                   (const git_commit **)parents);
     if (err < 0) {
         Error_set(err);
         goto out;
@@ -1701,7 +1703,7 @@ PyDoc_STRVAR(Repository_status__doc__,
   "    How to handle untracked files, defaults to \"all\":\n"
   "\n"
   "    - \"no\": do not return untracked files\n"
-  "    - \"normal\": include untracked files/directories but no dot recurse subdirectories\n"
+  "    - \"normal\": include untracked files/directories but do not recurse subdirectories\n"
   "    - \"all\": include all files in untracked directories\n"
   "\n"
   "    Using `untracked_files=\"no\"` or \"normal\"can be faster than \"all\" when the worktree\n"
